@@ -16,14 +16,13 @@
 
 'use strict';
 
-var extend      = require('extend');
+const extend = require('extend');
 
 module.exports = function alchemyErrorFormatter(cb) {
   return function(err, result, response) {
     if (err) {
       cb(err, result);
-    }
-    else {
+    } else {
       if (result.status !== 'OK') {
         err = new Error(result.statusInfo || response['headers']['x-alchemyapi-error-msg']);
         err.code = 400;
@@ -31,7 +30,7 @@ module.exports = function alchemyErrorFormatter(cb) {
         extend(err, result);
         result = null;
       }
-      cb(err, result)
+      cb(err, result);
     }
   };
 };
