@@ -16,41 +16,57 @@
 
 'use strict';
 
-var extend = require('extend');
-var helper = require('../lib/helper');
-var cookie = require('cookie');
-var pick = require('object.pick');
-var url = require('url');
-var https = require('https');
-var http = require('http');
-var isStream = require('isstream');
-var requestFactory = require('../lib/requestwrapper');
-var RecognizeStream = require('./recognize_stream');
-var pkg = require('../package.json'); // todo: consider using env properties here instead (to enable webpack support without requiring a plugin)
-var util = require('util');
-var BaseService = require('../lib/base_service');
-var async = require('async');
+const extend = require('extend');
+const helper = require('../lib/helper');
+const cookie = require('cookie');
+const pick = require('object.pick');
+const url = require('url');
+const https = require('https');
+const http = require('http');
+const isStream = require('isstream');
+const requestFactory = require('../lib/requestwrapper');
+const RecognizeStream = require('./recognize_stream');
+const pkg = require('../package.json'); // todo: consider using env properties here instead (to enable webpack support without requiring a plugin)
+const util = require('util');
+const BaseService = require('../lib/base_service');
+const async = require('async');
 
-var PARAMS_ALLOWED = ['continuous', 'max_alternatives', 'timestamps', 'word_confidence', 'inactivity_timeout',
-  'model', 'content-type', 'interim_results', 'keywords', 'keywords_threshold', 'word_alternatives_threshold',
-  'profanity_filter', 'smart_formatting', 'customization_id', 'speaker_labels'
+const PARAMS_ALLOWED = [
+  'continuous',
+  'max_alternatives',
+  'timestamps',
+  'word_confidence',
+  'inactivity_timeout',
+  'model',
+  'content-type',
+  'interim_results',
+  'keywords',
+  'keywords_threshold',
+  'word_alternatives_threshold',
+  'profanity_filter',
+  'smart_formatting',
+  'customization_id',
+  'speaker_labels'
 ];
 
 function formatChunk(chunk) {
   // Convert the string into an array
-  var result = chunk;
+  let result = chunk;
 
   // Check if in the stream doesn't have
   // two results together and parse them
-  if (!result || result.indexOf('}{') === -1)
-    {return JSON.parse(result);}
+  if (!result || result.indexOf('}{') === -1) {
+    return JSON.parse(result);
+  }
 
   // Check if we can parse the response
   try {
     result = '[' + result.replace(/}{/g, '},{') + ']';
     result = JSON.parse(result);
     return result[result.length - 1];
-  } catch (e) {} // eslint-disable-line no-empty
+  } catch (e) {
+    // if it fails, then this isn't valid json (or a concatenated list of valid json) - just return the original string
+  }
 
   return result;
 }
@@ -77,8 +93,7 @@ SpeechToTextV1.URL = 'https://stream.watsonplatform.net/speech-to-text/api';
  * @param {String} [params.content_type] - Content-type
  */
 SpeechToTextV1.prototype.recognize = function(params, callback) {
-
-  var missingParams = helper.getMissingParams(params, ['audio', 'content_type']);
+  const missingParams = helper.getMissingParams(params, ['audio', 'content_type']);
   if (missingParams) {
     callback(missingParams);
     return;
@@ -88,16 +103,16 @@ SpeechToTextV1.prototype.recognize = function(params, callback) {
     return;
   }
 
-  var queryParams = pick(params, PARAMS_ALLOWED);
+  const queryParams = pick(params, PARAMS_ALLOWED);
   if (Array.isArray(queryParams.keywords)) {
     queryParams.keywords = queryParams.keywords.join(',');
   }
 
-  var _url = '/v1';
-  _url += (params.session_id) ? ('/sessions/' + params.session_id) : '';
+  let _url = '/v1';
+  _url += params.session_id ? '/sessions/' + params.session_id : '';
   _url += '/recognize';
 
-  var parameters = {
+  const parameters = {
     options: {
       method: 'POST',
       url: _url,
@@ -105,14 +120,16 @@ SpeechToTextV1.prototype.recognize = function(params, callback) {
         'Content-Type': params.content_type
       },
       json: true,
-      qs: queryParams,
+      qs: queryParams
     },
     defaultOptions: this._options
   };
-  return params.audio.on('response', function(response) {
-    // Replace content-type
-    response.headers['content-type'] = params.content_type;
-  }).pipe(requestFactory(parameters, callback));
+  return params
+    .audio.on('response', function(response) {
+      // Replace content-type
+      response.headers['content-type'] = params.content_type;
+    })
+    .pipe(requestFactory(parameters, callback));
 };
 
 /**
@@ -126,31 +143,34 @@ SpeechToTextV1.prototype.recognize = function(params, callback) {
  * @deprecated use createRecognizeStream instead
  */
 SpeechToTextV1.prototype.recognizeLive = function(params, callback) {
-  var missingParams = helper.getMissingParams(params, ['session_id', 'content_type', 'cookie_session']);
+  const missingParams = helper.getMissingParams(params, ['session_id', 'content_type', 'cookie_session']);
 
   if (missingParams) {
     callback(missingParams);
     return;
   }
 
-  var serviceUrl = [this._options.url, '/v1/sessions/', params.session_id, '/recognize'].join('');
-  var parts = url.parse(serviceUrl);
-  var options = {
+  const serviceUrl = [this._options.url, '/v1/sessions/', params.session_id, '/recognize'].join('');
+  const parts = url.parse(serviceUrl);
+  const options = {
     agent: false,
     host: parts.hostname,
     port: parts.port,
     path: parts.pathname + (params.continuous ? '?continuous=true' : ''),
     method: 'POST',
-    headers: extend({
-      'Transfer-Encoding': 'chunked',
-      'cookie': 'SESSIONID=' + params.cookie_session,
-      'Content-type': params.content_type
-    }, this._options.headers)
+    headers: extend(
+      {
+        'Transfer-Encoding': 'chunked',
+        cookie: 'SESSIONID=' + params.cookie_session,
+        'Content-type': params.content_type
+      },
+      this._options.headers
+    )
   };
-  var protocol = (parts.protocol.match('http:')) ? http : https;
-  var recognize_req = protocol.request(options, function(result) {
+  const protocol = parts.protocol.match('http:') ? http : https;
+  const recognize_req = protocol.request(options, function(result) {
     result.setEncoding('utf-8');
-    var transcript = '';
+    let transcript = '';
 
     result.on('data', function(chunk) {
       transcript += chunk;
@@ -184,28 +204,29 @@ SpeechToTextV1.prototype.recognizeLive = function(params, callback) {
  * @deprecated use createRecognizeStream instead
  */
 SpeechToTextV1.prototype.observeResult = function(params, callback) {
-  var missingParams = helper.getMissingParams(params, ['session_id', 'cookie_session']);
+  const missingParams = helper.getMissingParams(params, ['session_id', 'cookie_session']);
   if (missingParams) {
     callback(missingParams);
     return;
   }
-  var serviceUrl = [this._options.url, '/v1/sessions/',
-    params.session_id, '/observe_result'
-  ].join('');
-  var parts = url.parse(serviceUrl);
-  var options = {
+  const serviceUrl = [this._options.url, '/v1/sessions/', params.session_id, '/observe_result'].join('');
+  const parts = url.parse(serviceUrl);
+  const options = {
     agent: false,
     host: parts.hostname,
     port: parts.port,
     path: parts.pathname + (params.interim_results ? '?interim_results=true' : ''),
     method: 'GET',
-    headers: extend({
-      'cookie': 'SESSIONID=' + params.cookie_session,
-      'Accept': 'application/json'
-    }, this._options.headers)
+    headers: extend(
+      {
+        cookie: 'SESSIONID=' + params.cookie_session,
+        Accept: 'application/json'
+      },
+      this._options.headers
+    )
   };
-  var protocol = (parts.protocol.match('http:')) ? http : https;
-  var req = protocol.request(options, function(result) {
+  const protocol = parts.protocol.match('http:') ? http : https;
+  const req = protocol.request(options, function(result) {
     result.setEncoding('utf-8');
     result.on('data', function(chunk) {
       try {
@@ -237,7 +258,7 @@ SpeechToTextV1.prototype.observeResult = function(params, callback) {
  * @deprecated use createRecognizeStream instead
  */
 SpeechToTextV1.prototype.getRecognizeStatus = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['session_id'],
     options: {
       method: 'GET',
@@ -258,7 +279,7 @@ SpeechToTextV1.prototype.getRecognizeStatus = function(params, callback) {
  * @returns {ReadableStream|undefined}
  */
 SpeechToTextV1.prototype.getModels = function(params, callback) {
-  var parameters = {
+  const parameters = {
     options: {
       method: 'GET',
       url: '/v1/models',
@@ -279,7 +300,7 @@ SpeechToTextV1.prototype.getModels = function(params, callback) {
  * @returns {ReadableStream|undefined}
  */
 SpeechToTextV1.prototype.getModel = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['model_id'],
     options: {
       method: 'GET',
@@ -301,7 +322,7 @@ SpeechToTextV1.prototype.getModel = function(params, callback) {
  * @param {string} params.model - The model to use during the session
  */
 SpeechToTextV1.prototype.createSession = function(params, callback) {
-  var parameters = {
+  const parameters = {
     options: {
       method: 'POST',
       url: '/v1/sessions',
@@ -318,7 +339,7 @@ SpeechToTextV1.prototype.createSession = function(params, callback) {
         cb(error, body, response);
         return;
       }
-      var cookies = cookie.parse(response.headers['set-cookie'][0]);
+      const cookies = cookie.parse(response.headers['set-cookie'][0]);
       body.cookie_session = cookies.SESSIONID;
       cb(error, body, response);
     };
@@ -334,20 +355,19 @@ SpeechToTextV1.prototype.createSession = function(params, callback) {
  * @param {String} params.session_id - Session id.
  */
 SpeechToTextV1.prototype.deleteSession = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['session_id'],
     options: {
       method: 'DELETE',
       url: '/v1/sessions/{session_id}',
       json: true,
-      path: pick(params, ['session_id']),
+      path: pick(params, ['session_id'])
     },
     defaultOptions: this._options
   };
   return requestFactory(parameters, callback);
 };
 
-
 /**
  * Replaces recognizeLive & friends with a single 2-way stream over websockets
  *
@@ -358,22 +378,29 @@ SpeechToTextV1.prototype.createRecognizeStream = function(params) {
   params = params || {};
   params.url = this._options.url;
 
-  params.headers = extend({
-    'user-agent': pkg.name + '-nodejs-' + pkg.version,
-    authorization: this._options.headers.Authorization
-  }, params.headers);
+  params.headers = extend(
+    {
+      'user-agent': pkg.name + '-nodejs-' + pkg.version,
+      authorization: this._options.headers.Authorization
+    },
+    params.headers
+  );
 
   return new RecognizeStream(params);
 };
 
 // set up a warning message for the deprecated methods
 ['recognizeLive', 'observeResult'].forEach(function(name) {
-  var original = SpeechToTextV1.prototype[name];
+  const original = SpeechToTextV1.prototype[name];
   SpeechToTextV1.prototype[name] = function deprecated(params) {
     if (!(params || {}).silent && !this._options.silent) {
       // eslint-disable-next-line no-console
-      console.log(new Error('The ' + name + '() method is deprecated and will be removed from a future version of the watson-developer-cloud SDK. ' +
-        'Please use createRecognizeStream() instead.\n(Set {silent: true} to hide this message.)'));
+      console.log(new Error(
+        'The ' +
+          name +
+          '() method is deprecated and will be removed from a future version of the watson-developer-cloud SDK. ' +
+          'Please use createRecognizeStream() instead.\n(Set {silent: true} to hide this message.)'
+      ));
     }
     return original.apply(this, arguments);
   };
@@ -397,7 +424,7 @@ SpeechToTextV1.prototype.createRecognizeStream = function(params) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.createCustomization = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['base_model_name', 'name'],
     options: {
       method: 'POST',
@@ -417,7 +444,6 @@ SpeechToTextV1.prototype.createCustomization = function(params, callback) {
  * @property {String} translation - The phonetic or sounds-like translation for the word. A phonetic translation is based on the SSML format for representing the phonetic string of a word either as an IPA or IBM SPR translation. A sounds-like translation consists of one or more words that, when combined, sound like the word.
  */
 
-
 /**
  * List all customizations
  *
@@ -463,7 +489,7 @@ SpeechToTextV1.prototype.getCustomizations = function(params, callback) {
     callback = params;
     params = {};
   }
-  var parameters = {
+  const parameters = {
     options: {
       method: 'GET',
       url: '/v1/customizations/',
@@ -498,7 +524,7 @@ SpeechToTextV1.prototype.getCustomizations = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.getCustomization = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'GET',
@@ -520,7 +546,7 @@ SpeechToTextV1.prototype.getCustomization = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.trainCustomization = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'POST',
@@ -542,7 +568,7 @@ SpeechToTextV1.prototype.trainCustomization = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.resetCustomization = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'POST',
@@ -563,7 +589,7 @@ SpeechToTextV1.prototype.resetCustomization = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.deleteCustomization = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'DELETE',
@@ -587,8 +613,7 @@ SpeechToTextV1.prototype.deleteCustomization = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.addCorpus = function(params, callback) {
-
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'name', 'corpus'],
     originalParams: params,
     options: {
@@ -603,7 +628,6 @@ SpeechToTextV1.prototype.addCorpus = function(params, callback) {
   return requestFactory(parameters, callback);
 };
 
-
 /**
  * List corpora
  *
@@ -632,7 +656,7 @@ SpeechToTextV1.prototype.addCorpus = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.getCorpora = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'GET',
@@ -666,7 +690,7 @@ SpeechToTextV1.prototype.getCorpora = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.getCorpus = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'name'],
     options: {
       method: 'GET',
@@ -688,7 +712,7 @@ SpeechToTextV1.prototype.getCorpus = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.deleteCorpus = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'name'],
     options: {
       method: 'DELETE',
@@ -701,7 +725,6 @@ SpeechToTextV1.prototype.deleteCorpus = function(params, callback) {
   return requestFactory(parameters, callback);
 };
 
-
 SpeechToTextV1.ERR_NO_CORPORA = 'ERR_NO_CORPORA';
 SpeechToTextV1.ERR_TIMEOUT = 'ERR_TIMEOUT';
 
@@ -719,43 +742,50 @@ SpeechToTextV1.ERR_TIMEOUT = 'ERR_TIMEOUT';
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.whenCustomizationReady = function(params, callback) {
-  var self = this;
+  const self = this;
 
-    // check the customization status repeatedly until it's ready or available
+  // check the customization status repeatedly until it's ready or available
 
-      var options = extend({
-        interval: 5000,
-        times: 30
-      }, params);
-      options.errorFilter = function(err) {
-        // if it's a timeout error, then getCustomization is called again after params.interval
-        // otherwise the error is passed back to the user
-        // if the params.times limit is reached, the error will be passed to the user regardless
-        return err.code === SpeechToTextV1.ERR_TIMEOUT;
-      };
-      async.retry(options, function(next) {
-        self.getCustomization(params, function(err, customization) {
-          if (err) {
-            next(err);
-          } else if (customization.status === 'pending' || customization.status === 'training') {
-            // if the loop times out, async returns the last error, which will be this one.
-            err = new Error('Customization is still pending, try increasing interval or times params');
-            err.code = SpeechToTextV1.ERR_TIMEOUT;
-            next(err);
-          } else if (customization.status === 'ready' || customization.status === 'available') {
-            next(null, customization);
-          } else if (customization.status === 'failed') {
-            next(new Error('Customization training failed'));
-          } else {
-            next(new Error('Unexpected customization status: ' + customization.status));
-          }
-        })
-      }, callback);
+  const options = extend(
+    {
+      interval: 5000,
+      times: 30
+    },
+    params
+  );
+  options.errorFilter = function(err) {
+    // if it's a timeout error, then getCustomization is called again after params.interval
+    // otherwise the error is passed back to the user
+    // if the params.times limit is reached, the error will be passed to the user regardless
+    return err.code === SpeechToTextV1.ERR_TIMEOUT;
+  };
+  async.retry(
+    options,
+    function(next) {
+      self.getCustomization(params, function(err, customization) {
+        if (err) {
+          next(err);
+        } else if (customization.status === 'pending' || customization.status === 'training') {
+          // if the loop times out, async returns the last error, which will be this one.
+          err = new Error('Customization is still pending, try increasing interval or times params');
+          err.code = SpeechToTextV1.ERR_TIMEOUT;
+          next(err);
+        } else if (customization.status === 'ready' || customization.status === 'available') {
+          next(null, customization);
+        } else if (customization.status === 'failed') {
+          next(new Error('Customization training failed'));
+        } else {
+          next(new Error('Unexpected customization status: ' + customization.status));
+        }
+      });
+    },
+    callback
+  );
 };
 
 // Check if there is a corpus that is still being processed
 function isProcessing(corporaList) {
-  var recordsBeingProcessed = corporaList.corpora.filter(function(record) {
+  const recordsBeingProcessed = corporaList.corpora.filter(function(record) {
     return record['status'] === 'being_processed';
   });
   if (recordsBeingProcessed.length === 0) {
@@ -767,7 +797,7 @@ function isProcessing(corporaList) {
 
 // Check if corpora has been analyzed
 function isAnalyzed(corporaList) {
-  var recordsAnalyzed = corporaList.corpora.filter(function(record) {
+  const recordsAnalyzed = corporaList.corpora.filter(function(record) {
     return record['status'] === 'analyzed';
   });
   if (recordsAnalyzed.length === corporaList.corpora.length) {
@@ -789,61 +819,68 @@ function isAnalyzed(corporaList) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.whenCorporaAnalyzed = function(params, callback) {
-  var self = this;
+  const self = this;
 
-  async.parallel([
-
-    // validate that it has at least one corpus
-    function(next) {
-      self.getCorpora(params, function(err, res) {
-        if (err) {
-          return next(err);
-        }
-        if (!res.corpora.length) {
-          err = new Error('Customization has no corpa and therefore corpus cannot be analyzed');
-          err.code = SpeechToTextV1.ERR_NO_CORPORA;
-          return next(err)
-        }
-        next();
-      })
-    },
-
-    // check the customization status repeatedly until it's available
-    function(next) {
-      var options = extend({
-        interval: 5000,
-        times: 30
-      }, params);
-      options.errorFilter = function(err) {
-        // if it's a timeout error, then getCorpora is called again after params.interval
-        // otherwise the error is passed back to the user
-        // if the params.times limit is reached, the error will be passed to the user regardless
-        return err.code === SpeechToTextV1.ERR_TIMEOUT;
-      };
-      async.retry(options, function(done) {
-        self.getCorpora(params, function(err, corpora) {
+  async.parallel(
+    [
+      // validate that it has at least one corpus
+      function(next) {
+        self.getCorpora(params, function(err, res) {
           if (err) {
-            done(err);
-          } else if (isProcessing(corpora)) {
-            // if the loop times out, async returns the last error, which will be this one.
-            err = new Error('Corpora is still being processed, try increasing interval or times params');
-            err.code = SpeechToTextV1.ERR_TIMEOUT;
-            done(err);
-          } else if (isAnalyzed(corpora)) {
-            done(null, corpora);
-          } else {
-            done(new Error('Unexpected corpus analysis status'));
+            return next(err);
           }
-        })
-      }, next)
+          if (!res.corpora.length) {
+            err = new Error('Customization has no corpa and therefore corpus cannot be analyzed');
+            err.code = SpeechToTextV1.ERR_NO_CORPORA;
+            return next(err);
+          }
+          next();
+        });
+      },
+      // check the customization status repeatedly until it's available
+      function(next) {
+        const options = extend(
+          {
+            interval: 5000,
+            times: 30
+          },
+          params
+        );
+        options.errorFilter = function(err) {
+          // if it's a timeout error, then getCorpora is called again after params.interval
+          // otherwise the error is passed back to the user
+          // if the params.times limit is reached, the error will be passed to the user regardless
+          return err.code === SpeechToTextV1.ERR_TIMEOUT;
+        };
+        async.retry(
+          options,
+          function(done) {
+            self.getCorpora(params, function(err, corpora) {
+              if (err) {
+                done(err);
+              } else if (isProcessing(corpora)) {
+                // if the loop times out, async returns the last error, which will be this one.
+                err = new Error('Corpora is still being processed, try increasing interval or times params');
+                err.code = SpeechToTextV1.ERR_TIMEOUT;
+                done(err);
+              } else if (isAnalyzed(corpora)) {
+                done(null, corpora);
+              } else {
+                done(new Error('Unexpected corpus analysis status'));
+              }
+            });
+          },
+          next
+        );
+      }
+    ],
+    function(err, res) {
+      if (err) {
+        return callback(err);
+      }
+      callback(null, res[1]); // callback with the final customization object
     }
-
-  ], function(err, res) {
-    if (err) {
-      return callback(err);
-    }
-    callback(null, res[1]); // callback with the final customization object
-  });
+  );
 };
 
 /**
@@ -855,7 +892,7 @@ SpeechToTextV1.prototype.whenCorporaAnalyzed = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.addWords = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'words'],
     options: {
       method: 'POST',
@@ -880,7 +917,7 @@ SpeechToTextV1.prototype.addWords = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.addWord = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'word', 'sounds_like'],
     options: {
       method: 'PUT',
@@ -943,7 +980,7 @@ SpeechToTextV1.prototype.getWords = function(params, callback) {
     callback = params;
     params = {};
   }
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id'],
     options: {
       method: 'GET',
@@ -978,7 +1015,7 @@ SpeechToTextV1.prototype.getWords = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.getWord = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'word'],
     options: {
       method: 'GET',
@@ -1002,7 +1039,7 @@ SpeechToTextV1.prototype.getWord = function(params, callback) {
  * @param {Function} callback
  */
 SpeechToTextV1.prototype.deleteWord = function(params, callback) {
-  var parameters = {
+  const parameters = {
     requiredParams: ['customization_id', 'word'],
     options: {
       method: 'DELETE',
@@ -1015,6 +1052,4 @@ SpeechToTextV1.prototype.deleteWord = function(params, callback) {
   return requestFactory(parameters, callback);
 };
 
-
-
 module.exports = SpeechToTextV1;
